from typing import Any

class LazyLoadedDocstring(str):
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def __new__(cls, *args: Any, **kwargs: Any) -> Any: ...
    def expandtabs(self, tabsize: Any = ...) -> str: ...
    def __str__(self) -> str: ...
    def __repr__(self) -> str: ...

class ClientMethodDocstring(LazyLoadedDocstring): ...
class WaiterDocstring(LazyLoadedDocstring): ...
class PaginatorDocstring(LazyLoadedDocstring): ...
